WhistleLoopSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WhistleLoopSdkPlatform
Implementers

Constructors

WhistleLoopSdkPlatform()
Constructs a WhistleLoopSdkPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConnectionType() → Future<String?>
getDate() → Future<String>
getDeviceType() → Future<String?>
getIP() → Future<String?>
getpac() → Future<String?>
getPlatform() → Future<String?>
getPlatformVersion() → Future<String?>
getTime() → Future<String>
initDeviceId() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ WhistleLoopSdkPlatform
The default instance of WhistleLoopSdkPlatform to use.
getter/setter pair