WhistleLoopSdkWeb class

A web implementation of the WhistleLoopSdkPlatform of the WhistleLoopSdk plugin.

Inheritance

Constructors

WhistleLoopSdkWeb()
Constructs a WhistleLoopSdkWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConnectionType() → Future<String?>
inherited
getDate() → Future<String>
inherited
getDeviceType() → Future<String?>
inherited
getIP() → Future<String?>
inherited
getpac() → Future<String?>
inherited
getPlatform() → Future<String?>
inherited
getPlatformVersion() → Future<String?>
Returns a String containing the version of the platform.
override
getTime() → Future<String>
inherited
initDeviceId() → Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void